@@ -1,8 +1,8 @@
 import functools
 import typing
 
-from horkos import schemaomatic
-from horkos import cataloger
+from horkos import _schemaomatic
+from horkos import _cataloger
 
 
 def oxford_join(values: typing.List[str], last: str = 'and') -> str:
@@ -25,8 +25,8 @@ def schema_not_in_catalog(func: typing.Callable) -> typing.Callable:
 
     @functools.wraps(func)
     def wrapper(
-            schema: schemaomatic.Schema,
-            catalog: cataloger.Catalog,
+            schema: _schemaomatic.Schema,
+            catalog: _cataloger.Catalog,
             *args,
             **kwargs,
     ):
